#pragma once

#include <stdint.h>
#include <string>
#include <sstream>

/**
 * @file group.hpp Class file for group address handling.
 */

namespace knx {

/**
 * @brief This class represents a KNX group address which might be either 3 compnent "a/b/c" or 2 component "a/b".
 */
class KNX_IMPORT_EXPORT group
{
public:
    //! Sets group to 0/0/0 by default.
    group();
    //! Assigns a group address by name. Sets default 0/0/0 if string is invalid. 2 component addresses may be used.
    group(std::string name);
    //! Binary assign a 3 component group address.
    group(uint8_t a, uint8_t b, uint8_t c);
    //! Binary assign a 2 component group address.
    group(uint8_t a, uint8_t b);
    /**
     * Gives the current set address as string.
     * @return The group address as string.
     */
    std::string get_name();
    /**
     * Get the binary group address value as 16 bit int.
     * @return Binary representation of the group address.
     */
    uint16_t get_binary();
    /**
     * Set the address by a set of components in the form "a/b/c". If any value exceeds the range higer bits are ignored.
     * @param a First component 5 bits (0-31).
     * @param b Second component 3 bits (0-7).
     * @param c Third component 8 bits (0-255).
     */
    void set_by_number(uint16_t a, uint16_t b, uint16_t c);
    /**
     * Set the address by a set of components in the form "a/b". If any value exceeds the range higer bits are ignored.
     * @param a First component 5 bits (0-31).
     * @param b Second component 11 bits (0-2047).
     */
    void set_by_number(uint16_t a, uint16_t b);
    /**
     * Set the address by name either as "1/2" or "1/2/3".
     */
    void set_by_name(std::string name);
    /**
     * Sets the whole address from binary value guessing a 2 comonent address in the form "a/b".
     * @param binary The address as 16 bit uint.
     */
    void set_by_binary_2(uint16_t binary);
    /**
     * Sets the whole address from binary value guessing a 3 comonent address in the form "a/b/c".
     * @param binary The address as 16 bit uint.
     */
    void set_by_binary_3(uint16_t binary);
    //! Comparison operator for rapid equality checks.
    bool operator==(knx::group other);
private:
    std::string name;
    uint16_t binary;
};

}



